@@ -3,10 +3,12 @@ from dataclasses import InitVar, dataclass, field
 from typing import Any, Dict, List, Optional, Union
 
 import requests
+from deprecation import deprecated  # type: ignore
 from mashumaro.mixins.json import DataClassJSONMixin  # type: ignore
 
 from .errors import SnykError, SnykNotImplementedError
 from .managers import Manager
+from .utils import flat_map, format_package
 
 
 @dataclass
@@ -81,7 +83,7 @@ class IssueData(DataClassJSONMixin):
     exploitMaturity: str
     description: Optional[str] = None
     identifiers: Optional[Any] = None
-    credit: Optional[str] = None
+    credit: Optional[List[str]] = None
     semver: Optional[Any] = None
     publicationTime: Optional[str] = None
     disclosureTime: Optional[str] = None
@@ -90,6 +92,18 @@ class IssueData(DataClassJSONMixin):
     language: Optional[str] = None
     patches: Optional[Any] = None
     nearestFixedInVersion: Optional[str] = None
+    ignoreReasons: Optional[List[Any]] = None
+
+
+@dataclass
+class FixInfo(DataClassJSONMixin):
+    isUpgradable: bool
+    isPinnable: bool
+    isPatchable: bool
+    isFixable: bool
+    isPartiallyFixable: bool
+    nearestFixedInVersion: str
+    fixedIn: List[str]
 
 
 @dataclass
@@ -101,9 +115,9 @@ class AggregatedIssue(DataClassJSONMixin):
     issueData: IssueData
     isPatched: bool
     isIgnored: bool
+    fixInfo: FixInfo
     introducedThrough: Optional[List[Any]] = None
     ignoreReasons: Optional[List[Any]] = None
-    fixInfo: Optional[Any] = None
     # Not mentioned in schema but returned
     # https://snyk.docs.apiary.io/#reference/projects/aggregated-project-issues/list-all-aggregated-issues
     priorityScore: Optional[int] = None
@@ -121,6 +135,27 @@ class OrganizationGroup(DataClassJSONMixin):
     id: str
 
 
+@dataclass
+class Package(DataClassJSONMixin):
+    name: str
+    version: str
+    fixVersion: Optional[str] = None
+
+
+@dataclass
+class IssuePaths(DataClassJSONMixin):
+    snapshotId: str
+    paths: List[List[Package]]
+    total: int
+
+
+@dataclass
+class IssueRelations:
+    id: str
+    organization_id: str
+    project_id: str
+
+
 @dataclass
 class Organization(DataClassJSONMixin):
     name: str
@@ -584,7 +619,9 @@ class Project(DataClassJSONMixin):
     def dependency_graph(self) -> DependencyGraph:
         return Manager.factory(DependencyGraph, self.organization.client, self).all()
 
-    @property
+    # mypy doesn't support decorated properties
+    @property  # type: ignore
+    @deprecated("Use issueset_aggregated")
     def issueset(self) -> Manager:
         return Manager.factory(IssueSet, self.organization.client, self)
 
@@ -594,7 +631,15 @@ class Project(DataClassJSONMixin):
 
     @property
     def vulnerabilities(self) -> List[Vulnerability]:
-        return self.issueset.all().issues.vulnerabilities
+        vuln_filter = {
+            "severities": ["critical", "high", "medium", "low"],
+            "types": ["vuln"],
+            "ignored": False,
+            "patched": False,
+        }
+        aggregated_vulns = self.issueset_aggregated.filter(**vuln_filter).issues
+        foo = flat_map(self._aggregated_issue_to_vulnerabily, aggregated_vulns)
+        return foo
 
     @property
     def tags(self) -> Manager:
@@ -604,3 +649,54 @@ class Project(DataClassJSONMixin):
     # https://snyk.docs.apiary.io/#reference/users/user-project-notification-settings/get-project-notification-settings
     def notification_settings(self):
         raise SnykNotImplementedError  # pragma: no cover
+
+    def _aggregated_issue_to_vulnerabily(
+        self, issue: AggregatedIssue
+    ) -> List[Vulnerability]:
+        issue_paths = Manager.factory(
+            IssuePaths,
+            self.organization.client,
+            IssueRelations(
+                id=issue.id, organization_id=self.organization.id, project_id=self.id
+            ),
+        ).all()
+
+        try:
+            upgrade_path = next(
+                filter(lambda path: path[0].fixVersion is not None, issue_paths.paths)
+            ).map(format_package)
+        except StopIteration:
+            upgrade_path = []
+
+        return [
+            Vulnerability(
+                id=issue.issueData.id,
+                url=issue.issueData.url,
+                title=issue.issueData.title,
+                description=issue.issueData.description or "",
+                upgradePath=upgrade_path,
+                package=issue.pkgName,
+                version=version,
+                severity=issue.issueData.severity,
+                exploitMaturity=issue.issueData.exploitMaturity,
+                isUpgradable=issue.fixInfo.isUpgradable,
+                isPatchable=issue.fixInfo.isPatchable,
+                isPinnable=issue.fixInfo.isPinnable,
+                identifiers=issue.issueData.identifiers,
+                semver=issue.issueData.semver,
+                fromPackages=issue.introducedThrough or [],
+                language=issue.issueData.language,
+                packageManager=self.type,
+                publicationTime=issue.issueData.publicationTime,
+                priorityScore=issue.priorityScore,
+                disclosureTime=issue.issueData.disclosureTime,
+                credit=issue.issueData.credit,
+                CVSSv3=issue.issueData.CVSSv3,
+                cvssScore=issue.issueData.cvssScore,
+                ignored=issue.issueData.ignoreReasons,
+                patched=issue.issueData.patches if issue.isPatched else [],
+            )
+            # Old endpoint returned a new issue if it appeared in multiple
+            # versions, emulate that here to preserve upstream api
+            for version in issue.pkgVersions
+        ]
